#
# spec file for package python-natsort
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


Name:           python-natsort
Version:        3.5.2
Release:        1.2
License:        MIT
Summary:        Sort lists naturally
Url:            https://github.com/SethMMorton/natsort
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/n/natsort/natsort-%{version}.tar.gz
Source1:        natsort.1
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  python-pytest
BuildRequires:  python-pytest-cov
BuildRequires:  help2man
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Natural sorting for python. natsort requires python version 2.6 or greater
(this includes python 3.x). To run version 2.6, 3.0, or 3.1 the 
argparse module is required.

natsort comes with a shell script. You can
also execute natsort from the command line with python -m natsort

%prep
%setup -q -n natsort-%{version}

%build
python setup.py build
%if 0%{?suse_version} >= 1230
help2man -o natsort.1 --name=natsort --version-string=3.3.0 -N "python -m natsort"
sed -i 's/PYTHON/NATSORT/g;s/python -m natsort/natsort/g;s/python/natsort/g;s/__main__.py/natsort/g' natsort.1
%else
# don't bother too old help2man....
sed -e 's/VERSION_STRING/%version/g' %{S:1}  > natsort.1
%endif

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -Dm0644 natsort.1 %{buildroot}%{_mandir}/man1/natsort-%{py_ver}.1

# move executables to python-specific names
mv %{buildroot}%{_bindir}/natsort %{buildroot}%{_bindir}/natsort-%{py_ver}

# Prepare for update-alternatives usage
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/natsort
touch %{buildroot}%{_sysconfdir}/alternatives/natsort.1.gz
ln -s -f %{_sysconfdir}/alternatives/natsort %{buildroot}%{_bindir}/natsort
ln -s -f %{_sysconfdir}/alternatives/natsort.1.gz %{buildroot}%{_mandir}/man1/natsort.1.gz

%post
update-alternatives \
   --install %{_bindir}/natsort natsort %{_bindir}/natsort-%{py_ver} 30 \
   --slave %{_mandir}/man1/natsort.1.gz natsort.1.gz  %{_mandir}/man1/natsort-%{py_ver}.1.gz

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove natsort %{_bindir}/natsort-%{py_ver}
fi

%files
%defattr(-,root,root,-)
%{_bindir}/natsort
%{_mandir}/man1/natsort.1.gz
%{_bindir}/natsort-%{py_ver}
%{_mandir}/man1/natsort-%{py_ver}.1.gz
%ghost %{_sysconfdir}/alternatives/natsort
%ghost %{_sysconfdir}/alternatives/natsort.1.gz
%{python_sitelib}/*

%changelog
* Tue Feb  3 2015 toddrme2178@gmail.com
- Update to 3.5.2
  - Enhancement that will convert a 'pathlib.Path' object to a 'str' if
    'ns.PATH' is enabled.
- Update to 3.5.1
  - Fixed bug that caused list/tuples to fail when using 'ns.LOWECASEFIRST'
    or 'ns.IGNORECASE'.
  - Refactored modules so that only the public API was in natsort.py and
    ns_enum.py.
  - Refactored all import statements to be absolute, not relative.
- Update to 3.5.0
  - Added the 'alg' argument to the 'natsort' functions.  This argument
    accepts an enum that is used to indicate the options the user wishes
    to use.  The 'number_type', 'signed', 'exp', 'as_path', and 'py3_safe'
    options are being depreciated and will become (undocumented)
    keyword-only options in natsort version 4.0.0.
  - The user can now modify how 'natsort' handles the case of non-numeric
    characters.
  - The user can now instruct 'natsort' to use locale-aware sorting, which
    allows 'natsort' to perform true "human sorting".
  - The `humansorted` convenience function has been included to make this
    easier.
  - Updated shell script with locale functionality.
- Update to 3.4.1
  - 'natsort' will now use the 'fastnumbers' module if it is installed. This
    gives up to an extra 30%% boost in speed over the previous performance
    enhancements.
  - Made documentation point to more 'natsort' resources, and also added a
    new example in the examples section.
- Update to 3.4.0
  - Fixed a bug that caused user's options to the 'natsort_key' to not be
    passed on to recursive calls of 'natsort_key'.
  - Added a 'natsort_keygen' function that will generate a wrapped version
    of 'natsort_key' that is easier to call.  'natsort_key' is now set to
    depreciate at natsort version 4.0.0.
  - Added an 'as_path' option to 'natsorted' & co. that will try to treat
    input strings as filepaths. This will help yield correct results for
    OS-generated inputs like
    ``['/p/q/o.x', '/p/q (1)/o.x', '/p/q (10)/o.x', '/p/q/o (1).x']``.
  - Massive performance enhancements for string input (1.8x-2.0x), at the expense
    of reduction in speed for numeric input (~2.0x).
  - This is a good compromise because the most common input will be strings,
    not numbers, and sorting numbers still only takes 0.6x the time of sorting
    strings.  If you are sorting only numbers, you would use 'sorted' anyway.
  - Added the 'order_by_index' function to help in using the output of
    'index_natsorted' and 'index_versorted'.
  - Added the 'reverse' option to 'natsorted' & co. to make it's API more
    similar to the builtin 'sorted'.
  - Added more unit tests.
  - Added auxillary test code that helps in profiling and stress-testing.
  - Reworked the documentation, moving most of it to PyPI's hosting platform.
  - Added support for coveralls.io.
  - Entire codebase is now PyFlakes and PEP8 compliant.
- Implement update-alternatives for upcoming python 3 version.
* Sat Jul 12 2014 boris@steki.net
- initial packaging of 3.3.0 version
